# THIS FILE IS AUTOGENERATED BY DBIx::Skinny::Schema::Loader 0.17, DO NOT EDIT DIRECTLY.

package Hello::DB::Schema;
use DBIx::Skinny::Schema;

install_table entry => schema {
    pk qw/entry_id/;
    columns qw/entry_id body/;
};

1;